@@ -1,6 +1,6 @@
 # Messaging.py
 # Credits: 
-#   this module largely builds on the concepts of a trigger system introduced in
+#   this module builds on the concepts of a trigger system introduced in
 #   the book: "Game Coding Complete - 2nd Edition" by Mike McShaffry
 # this module implements a message manager along with message receivers
 import util
@@ -8,17 +8,11 @@ import threading
 import collections
 import time
 
+__all__ = ['InvalidMessageProperty', 'GroupAlreadyExists', 'GroupDoesNotExist', 'InvalidGroupName']
+
 WildCardMessageType = '*'
 PySageInternalMainGroup = '__MAIN_GROUP__'
 
-def MessageID():
-    '''generates unique message IDs per runtime'''
-    i = 0
-    while True:
-        yield i
-        i += 1
-messageID = MessageID()
-
 class InvalidMessageProperty(Exception):
     pass
 
@@ -64,8 +58,10 @@ class Message(object):
         for name, value in kws.items():
             self.lazySetProperty(name, value)
         self.sender = sender
-        self.gid = messageID.next()
+        self.gid = self.assign_id()
         self.receiverID = receiverID
+    def assign_id(self):
+        return str(id(self))
     def __repr__(self):
         return 'Message %s %s' % (self.messageType, self.gid)
     @property
